@@ -13,8 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import print_function
-
 import numbers
 
 import prettytable
@@ -42,7 +40,8 @@ def arg(*args, **kwargs):
 
 
 def json_formatter(js):
-    return (jsonutils.dumps(js, indent=2, ensure_ascii=False)).encode('utf-8')
+    formatter = (jsonutils.dumps(js, indent=2, ensure_ascii=False))
+    return formatter if six.PY3 else formatter.encode('utf-8')
 
 
 def print_list(objs, fields, field_labels=None, formatters=None, sortby=None):
@@ -65,10 +64,9 @@ def print_list(objs, fields, field_labels=None, formatters=None, sortby=None):
                 data = getattr(o, field, None) or ''
                 row.append(data)
         pt.add_row(row)
-    if sortby is None:
-        print(pt.get_string().encode('utf-8'))
-    else:
-        print(pt.get_string(sortby=field_labels[sortby]).encode('utf-8'))
+    field_to_sort_by = field_labels[sortby] if sortby else None
+    pt_string = pt.get_string(sortby=field_to_sort_by)
+    print(pt_string if six.PY3 else pt_string.encode('utf-8'))
 
 
 def print_dict(d, formatters=None):
@@ -78,12 +76,14 @@ def print_dict(d, formatters=None):
                                  caching=False, print_empty=False)
     pt.align = 'l'
 
-    for field in d.keys():
+    for field in d:
         if field in formatters:
             pt.add_row([field, formatters[field](d[field])])
         else:
             pt.add_row([field, d[field]])
-    print(pt.get_string(sortby='Property').encode('utf-8'))
+
+    pt_string = pt.get_string(sortby='Property')
+    print(pt_string if six.PY3 else pt_string.encode('utf-8'))
 
 
 def format_parameters(params):
@@ -198,4 +198,4 @@ def format_list(in_list):
         else:
             key = k
         string_list.append(key)
-    return '\n'.join(string_list)
+    return b'\n'.join(string_list)
